==> PhysX-4.0.zip: PhysX-4.0/physx/documentation/PhysXAPI/files/search/all_e.js <==
var searchData=
[
  ['n',['n',['../classPxPlane.html#a5697986eb1240eafe0261f453c5a7065',1,'PxPlane']]],
  ['name',['name',['../structPxMetaDataEntry.html#a5fb361c8856029844ac694f01d31f5d3',1,'PxMetaDataEntry']]],
  ['narrowphaseparams',['NarrowPhaseParams',['../structphysx_1_1Gu_1_1NarrowPhaseParams.html',1,'physx::Gu::NarrowPhaseParams'],['../structphysx_1_1Gu_1_1NarrowPhaseParams.html#a7e06ecf33181a9a53ea833ee097943be',1,'physx::Gu::NarrowPhaseParams::NarrowPhaseParams()']]],
  ['nbactiveconstraints',['nbActiveConstraints',['../classPxSimulationStatistics.html#a3ba1901c4ac662c535daa1ac58987aba',1,'PxSimulationStatistics']]],
  ['nbactivedynamicbodies',['nbActiveDynamicBodies',['../classPxSimulationStatistics.html#adb8e7d0a9d70b16a4b7309c4d47685e2',1,'PxSimulationStatistics']]],
  ['nbactivekinematicbodies',['nbActiveKinematicBodies',['../classPxSimulationStatistics.html#af783cd541d93f5f72b64f07cebbbe71a',1,'PxSimulationStatistics']]],
  ['nbaggregates',['nbAggregates',['../classPxSimulationStatistics.html#a4903606cb701b7237a92a6a43f8d60ea',1,'PxSimulationStatistics']]],
  ['nbarticulations',['nbArticulations',['../classPxSimulationStatistics.html#abfd24df0bcef58fccc82cd06423aeff2',1,'PxSimulationStatistics']]],
  ['nbaxissolverconstraints',['nbAxisSolverConstraints',['../classPxSimulationStatistics.html#a9b03e0dc11df05eea8ded2e95d01fdcf',1,'PxSimulationStatistics']]],
  ['nbbroadphaseadds',['nbBroadPhaseAdds',['../classPxSimulationStatistics.html#a832a4823ac63af2716b4132aad10b51c',1,'PxSimulationStatistics']]],
  ['nbbroadphaseremoves',['nbBroadPhaseRemoves',['../classPxSimulationStatistics.html#ac086bc02b779c42c0b38f09c2fde294b',1,'PxSimulationStatistics']]],
  ['nbccdpairs',['nbCCDPairs',['../classPxSimulationStatistics.html#a3a3e17aed5223a69ba3b832f909a6a59',1,'PxSimulationStatistics']]],
  ['nbcolumns',['nbColumns',['../classPxHeightFieldDesc.html#a8426b15eb6ad44c11fcb84bb9e3350c0',1,'PxHeightFieldDesc::nbColumns()'],['../classPxKinematicJacobian.html#aaf6d1dd5689d3f82863a1fac901392f7',1,'PxKinematicJacobian::nbColumns()']]],
  ['nbconcurrentwheelupdates',['nbConcurrentWheelUpdates',['../structPxVehicleConcurrentUpdateData.html#ab38adafb3d3f9a3879088b1ec6ab35d2',1,'PxVehicleConcurrentUpdateData']]],
  ['nbcontactdatablocks',['nbContactDataBlocks',['../classPxSceneDesc.html#a625cdbae7d2149a9df472fb4f9c06f83',1,'PxSceneDesc']]],
  ['nbcontacts',['nbContacts',['../structPxContactPatch.html#a7b3b618ffe8837691cb56543a7462e66',1,'PxContactPatch::nbContacts()'],['../PxContact_8h.html#ae377550fb9bb881c6514f5fc3a165d1d',1,'nbContacts():&#160;PxContact.h']]],
  ['nbdiscretecontactpairs',['nbDiscreteContactPairs',['../classPxSimulationStatistics.html#a97dfe63f126e504699c8eeda86ebcb28',1,'PxSimulationStatistics']]],
  ['nbdiscretecontactpairstotal',['nbDiscreteContactPairsTotal',['../classPxSimulationStatistics.html#a6310732fffde7fa5013aada6ca2434c1',1,'PxSimulationStatistics']]],
  ['nbdiscretecontactpairswithcachehits',['nbDiscreteContactPairsWithCacheHits',['../classPxSimulationStatistics.html#afc4203ee9a309b63e0a9638595d28867',1,'PxSimulationStatistics']]],
  ['nbdiscretecontactpairswithcontacts',['nbDiscreteContactPairsWithContacts',['../classPxSimulationStatistics.html#a897bc3a4b6dc809b1f04059fe4b4a2af',1,'PxSimulationStatistics']]],
  ['nbdynamicbodies',['nbDynamicBodies',['../classPxSimulationStatistics.html#a1d5feb904597a5a98d02f39707e6c349',1,'PxSimulationStatistics']]],
  ['nbdynamicobjects',['nbDynamicObjects',['../structPxBroadPhaseRegionInfo.html#a2bcc9f7a41d0b93cb85b484fba871875',1,'PxBroadPhaseRegionInfo']]],
  ['nbfullupdates',['nbFullUpdates',['../structPxControllerStats.html#ab0ef64e5e2d677d2c62ad04ff150db9b',1,'PxControllerStats']]],
  ['nbiterations',['nbIterations',['../structPxControllerStats.html#a21f83b28a7113c641e2330c1490704d3',1,'PxControllerStats']]],
  ['nblostpairs',['nbLostPairs',['../classPxSimulationStatistics.html#a84b14e904af17d9c86d158ecea5fb9d1',1,'PxSimulationStatistics']]],
  ['nblosttouches',['nbLostTouches',['../classPxSimulationStatistics.html#ae20e0fabfd1e8dfdec622a496bfbaf83',1,'PxSimulationStatistics']]],
  ['nbmodifiedcontactpairs',['nbModifiedContactPairs',['../classPxSimulationStatistics.html#aade3e5f9699bfd0858786f9ed6b7d1c9',1,'PxSimulationStatistics']]],
  ['nbnewpairs',['nbNewPairs',['../classPxSimulationStatistics.html#a717bce9ff3da25dd9250c1746008e52b',1,'PxSimulationStatistics']]],
  ['nbnewtouches',['nbNewTouches',['../classPxSimulationStatistics.html#a612d72aad0d4e7adab3bbb5f14135bf1',1,'PxSimulationStatistics']]],
  ['nbpairs',['nbPairs',['../structPxContactPairHeader.html#aa4b544da63d06205662034a5ebaf1e9f',1,'PxContactPairHeader']]],
  ['nbpartialupdates',['nbPartialUpdates',['../structPxControllerStats.html#aa3d6b4144484bf5d7735011766d40a78',1,'PxControllerStats']]],
  ['nbpartitions',['nbPartitions',['../classPxSimulationStatistics.html#aab9b2646eb89d7fb3bb707256be46cf0',1,'PxSimulationStatistics']]],
  ['nbrows',['nbRows',['../classPxHeightFieldDesc.html#ac701700af3c4597a4a39a76e3331dd08',1,'PxHeightFieldDesc']]],
  ['nbshapes',['nbShapes',['../classPxSimulationStatistics.html#a2385b3afe6fc6237f7fcbb4712e4ad57',1,'PxSimulationStatistics']]],
  ['nbstaticbodies',['nbStaticBodies',['../classPxSimulationStatistics.html#a8aebb151f3f50cd831f2a42165ef9409',1,'PxSimulationStatistics']]],
  ['nbstaticobjects',['nbStaticObjects',['../structPxBroadPhaseRegionInfo.html#a42c387fdc3547b80af62d3e671a5af81',1,'PxBroadPhaseRegionInfo']]],
  ['nbtessellation',['nbTessellation',['../structPxControllerStats.html#a469b51d5beff9d726b4375c48a134d1e',1,'PxControllerStats']]],
  ['nbtouches',['nbTouches',['../structPxBatchQueryResult.html#aac884d117477c6f480d9ceb53d229ead',1,'PxBatchQueryResult::nbTouches()'],['../structPxHitCallback.html#a549f6828e98c9aeaee9012defa100f74',1,'PxHitCallback::nbTouches()']]],
  ['nbtriggerpairs',['nbTriggerPairs',['../classPxSimulationStatistics.html#abcb6c70a6d7e5146767b0be74db34cde',1,'PxSimulationStatistics']]],
  ['nbwheelqueryresults',['nbWheelQueryResults',['../structPxVehicleWheelQueryResult.html#a60678dd75d1ef6335324e4e9987e044f',1,'PxVehicleWheelQueryResult']]],
  ['needspredefinedbounds',['needsPredefinedBounds',['../structPxBroadPhaseCaps.html#aaff9d2a811a6863dea9939ecb2f26e58',1,'PxBroadPhaseCaps']]],
  ['nextcontact',['nextContact',['../structPxContactStreamIterator.html#a7e153b25314fff172bca67a660ccc8c8',1,'PxContactStreamIterator']]],
  ['nextcontactindex',['nextContactIndex',['../structPxContactStreamIterator.html#a9be505b3ff688521967f7b37feb2f898',1,'PxContactStreamIterator']]],
  ['nextitemset',['nextItemSet',['../structPxContactPairExtraDataIterator.html#a6938e71e6ed8d693a4fe9e1bd3bd9d3a',1,'PxContactPairExtraDataIterator']]],
  ['nextpatch',['nextPatch',['../structPxContactStreamIterator.html#a46de7820400eb295b621f38c79884867',1,'PxContactStreamIterator']]],
  ['nextpatchindex',['nextPatchIndex',['../structPxContactStreamIterator.html#a54397b4d83a700d42ded55dfd6f220ac',1,'PxContactStreamIterator']]],
  ['no_5flink',['NO_LINK',['../structPxSolverConstraintDesc.html#a87d502cd319544604669cb843a239fb0',1,'PxSolverConstraintDesc']]],
  ['nodeindex',['nodeIndex',['../structPxSolverBodyData.html#ac01024b5307ea57e79c7891d89906296',1,'PxSolverBodyData']]],
  ['nonwalkablemode',['nonWalkableMode',['../classPxControllerDesc.html#ad8286ec8cdb374997b9902a1ef21192c',1,'PxControllerDesc']]],
  ['normal',['normal',['../structPxLocationHit.html#a0e4815489090f4faced5e91f6f6cd336',1,'PxLocationHit::normal()'],['../structPxContactPairPoint.html#a36ae08a170895b4b57eaa1f6488bcd05',1,'PxContactPairPoint::normal()'],['../classPxTriangle.html#afb3fd7854de70dad3983f0e0f21809d6',1,'PxTriangle::normal()']]],
  ['normalize',['normalize',['../structPxExtendedVec3.html#a437090f727eed9091297ebe303b4e36c',1,'PxExtendedVec3::normalize()'],['../classPxPlane.html#a37c94eda03f24e3caed2e7739940c14a',1,'PxPlane::normalize()'],['../classPxQuat.html#a77a42662202126a13f2f9fc12013fe70',1,'PxQuat::normalize()'],['../classPxVec2.html#a4c115c5ab9863553c558518f8b1b4d33',1,'PxVec2::normalize()'],['../classPxVec3.html#ab67c4b05db03b0ceeddc74b1f6f77af5',1,'PxVec3::normalize()'],['../classPxVec4.html#a1c40877f3e03054cbd08a48fc9039cd4',1,'PxVec4::normalize()']]],
  ['normalizefast',['normalizeFast',['../classPxVec3.html#abe30659678fa294743b2eaabe69a8689',1,'PxVec3']]],
  ['normalizesafe',['normalizeSafe',['../classPxVec3.html#a69edea41dcd58f35d35036026bf75dcc',1,'PxVec3']]],
  ['num_5fgpu_5ftask_5fhints',['NUM_GPU_TASK_HINTS',['../structphysx_1_1PxGpuTaskHint.html#ad04073eff7b52fedb0f551f7583bbc80abc8bb0ca370c3819f7da087a48fdf84a',1,'physx::PxGpuTaskHint']]],
  ['numcontactpatches',['numContactPatches',['../structPxSolverContactDesc.html#a2261ea42204894094ada177641222c9a',1,'PxSolverContactDesc']]],
  ['numcontacts',['numContacts',['../structPxSolverContactDesc.html#ae2a5692ebc3c99c68ac34828d15ef56d',1,'PxSolverContactDesc']]],
  ['numfrictionpatches',['numFrictionPatches',['../structPxSolverContactDesc.html#ada1b86bf21e1dd614e7e4a07a9c990dd',1,'PxSolverContactDesc']]],
  ['numprimsperleaf',['numPrimsPerLeaf',['../structPxBVH34MidphaseDesc.html#aa70a3cfbaeff0b25b86f9584760ae563',1,'PxBVH34MidphaseDesc']]],
  ['numrows',['numRows',['../structPxSolverConstraintPrepDesc.html#a70cd18a2d279f25baab00ef7838dec16',1,'PxSolverConstraintPrepDesc']]]
];

==> PhysX-4.1.zip: PhysX-4.1/physx/documentation/PhysXAPI/files/search/all_e.js <==
var searchData=
[
  ['n',['n',['../classPxPlane.html#a5697986eb1240eafe0261f453c5a7065',1,'PxPlane']]],
  ['name',['name',['../structPxMetaDataEntry.html#a5fb361c8856029844ac694f01d31f5d3',1,'PxMetaDataEntry']]],
  ['narrowphaseparams',['NarrowPhaseParams',['../structphysx_1_1Gu_1_1NarrowPhaseParams.html',1,'physx::Gu::NarrowPhaseParams'],['../structphysx_1_1Gu_1_1NarrowPhaseParams.html#a7e06ecf33181a9a53ea833ee097943be',1,'physx::Gu::NarrowPhaseParams::NarrowPhaseParams()']]],
  ['nbactiveconstraints',['nbActiveConstraints',['../classPxSimulationStatistics.html#a3ba1901c4ac662c535daa1ac58987aba',1,'PxSimulationStatistics']]],
  ['nbactivedynamicbodies',['nbActiveDynamicBodies',['../classPxSimulationStatistics.html#adb8e7d0a9d70b16a4b7309c4d47685e2',1,'PxSimulationStatistics']]],
  ['nbactivekinematicbodies',['nbActiveKinematicBodies',['../classPxSimulationStatistics.html#af783cd541d93f5f72b64f07cebbbe71a',1,'PxSimulationStatistics']]],
  ['nbaggregates',['nbAggregates',['../classPxSimulationStatistics.html#a4903606cb701b7237a92a6a43f8d60ea',1,'PxSimulationStatistics']]],
  ['nbarticulations',['nbArticulations',['../classPxSimulationStatistics.html#abfd24df0bcef58fccc82cd06423aeff2',1,'PxSimulationStatistics']]],
  ['nbaxissolverconstraints',['nbAxisSolverConstraints',['../classPxSimulationStatistics.html#a9b03e0dc11df05eea8ded2e95d01fdcf',1,'PxSimulationStatistics']]],
  ['nbbroadphaseadds',['nbBroadPhaseAdds',['../classPxSimulationStatistics.html#a832a4823ac63af2716b4132aad10b51c',1,'PxSimulationStatistics']]],
  ['nbbroadphaseremoves',['nbBroadPhaseRemoves',['../classPxSimulationStatistics.html#ac086bc02b779c42c0b38f09c2fde294b',1,'PxSimulationStatistics']]],
  ['nbccdpairs',['nbCCDPairs',['../classPxSimulationStatistics.html#a3a3e17aed5223a69ba3b832f909a6a59',1,'PxSimulationStatistics']]],
  ['nbcolumns',['nbColumns',['../classPxHeightFieldDesc.html#a8426b15eb6ad44c11fcb84bb9e3350c0',1,'PxHeightFieldDesc']]],
  ['nbconcurrentwheelupdates',['nbConcurrentWheelUpdates',['../structPxVehicleConcurrentUpdateData.html#ab38adafb3d3f9a3879088b1ec6ab35d2',1,'PxVehicleConcurrentUpdateData']]],
  ['nbcontactdatablocks',['nbContactDataBlocks',['../classPxSceneDesc.html#a625cdbae7d2149a9df472fb4f9c06f83',1,'PxSceneDesc']]],
  ['nbcontacts',['nbContacts',['../structPxContactPatch.html#a7b3b618ffe8837691cb56543a7462e66',1,'PxContactPatch::nbContacts()'],['../PxContact_8h.html#ae377550fb9bb881c6514f5fc3a165d1d',1,'nbContacts():&#160;PxContact.h']]],
  ['nbdiscretecontactpairs',['nbDiscreteContactPairs',['../classPxSimulationStatistics.html#a97dfe63f126e504699c8eeda86ebcb28',1,'PxSimulationStatistics']]],
  ['nbdiscretecontactpairstotal',['nbDiscreteContactPairsTotal',['../classPxSimulationStatistics.html#a6310732fffde7fa5013aada6ca2434c1',1,'PxSimulationStatistics']]],
  ['nbdiscretecontactpairswithcachehits',['nbDiscreteContactPairsWithCacheHits',['../classPxSimulationStatistics.html#afc4203ee9a309b63e0a9638595d28867',1,'PxSimulationStatistics']]],
  ['nbdiscretecontactpairswithcontacts',['nbDiscreteContactPairsWithContacts',['../classPxSimulationStatistics.html#a897bc3a4b6dc809b1f04059fe4b4a2af',1,'PxSimulationStatistics']]],
  ['nbdynamicbodies',['nbDynamicBodies',['../classPxSimulationStatistics.html#a1d5feb904597a5a98d02f39707e6c349',1,'PxSimulationStatistics']]],
  ['nbdynamicobjects',['nbDynamicObjects',['../structPxBroadPhaseRegionInfo.html#a2bcc9f7a41d0b93cb85b484fba871875',1,'PxBroadPhaseRegionInfo']]],
  ['nbfullupdates',['nbFullUpdates',['../structPxControllerStats.html#ab0ef64e5e2d677d2c62ad04ff150db9b',1,'PxControllerStats']]],
  ['nbiterations',['nbIterations',['../structPxControllerStats.html#a21f83b28a7113c641e2330c1490704d3',1,'PxControllerStats']]],
  ['nbkinematicbodies',['nbKinematicBodies',['../classPxSimulationStatistics.html#a38012209b56e1e6993e0955f3a5606d2',1,'PxSimulationStatistics']]],
  ['nblostpairs',['nbLostPairs',['../classPxSimulationStatistics.html#a84b14e904af17d9c86d158ecea5fb9d1',1,'PxSimulationStatistics']]],
  ['nblosttouches',['nbLostTouches',['../classPxSimulationStatistics.html#ae20e0fabfd1e8dfdec622a496bfbaf83',1,'PxSimulationStatistics']]],
  ['nbmodifiedcontactpairs',['nbModifiedContactPairs',['../classPxSimulationStatistics.html#aade3e5f9699bfd0858786f9ed6b7d1c9',1,'PxSimulationStatistics']]],
  ['nbnewpairs',['nbNewPairs',['../classPxSimulationStatistics.html#a717bce9ff3da25dd9250c1746008e52b',1,'PxSimulationStatistics']]],
  ['nbnewtouches',['nbNewTouches',['../classPxSimulationStatistics.html#a612d72aad0d4e7adab3bbb5f14135bf1',1,'PxSimulationStatistics']]],
  ['nbpairs',['nbPairs',['../structPxContactPairHeader.html#aa4b544da63d06205662034a5ebaf1e9f',1,'PxContactPairHeader']]],
  ['nbpartialupdates',['nbPartialUpdates',['../structPxControllerStats.html#aa3d6b4144484bf5d7735011766d40a78',1,'PxControllerStats']]],
  ['nbpartitions',['nbPartitions',['../classPxSimulationStatistics.html#aab9b2646eb89d7fb3bb707256be46cf0',1,'PxSimulationStatistics']]],
  ['nbrows',['nbRows',['../classPxHeightFieldDesc.html#ac701700af3c4597a4a39a76e3331dd08',1,'PxHeightFieldDesc']]],
  ['nbshapes',['nbShapes',['../classPxSimulationStatistics.html#a2385b3afe6fc6237f7fcbb4712e4ad57',1,'PxSimulationStatistics']]],
  ['nbstaticbodies',['nbStaticBodies',['../classPxSimulationStatistics.html#a8aebb151f3f50cd831f2a42165ef9409',1,'PxSimulationStatistics']]],
  ['nbstaticinteractions',['nbStaticInteractions',['../structPxTGSSolverBodyVel.html#a024740f7b599adb152a938b55c153709',1,'PxTGSSolverBodyVel']]],
  ['nbstaticobjects',['nbStaticObjects',['../structPxBroadPhaseRegionInfo.html#a42c387fdc3547b80af62d3e671a5af81',1,'PxBroadPhaseRegionInfo']]],
  ['nbtessellation',['nbTessellation',['../structPxControllerStats.html#a469b51d5beff9d726b4375c48a134d1e',1,'PxControllerStats']]],
  ['nbtouches',['nbTouches',['../structPxBatchQueryResult.html#aac884d117477c6f480d9ceb53d229ead',1,'PxBatchQueryResult::nbTouches()'],['../structPxHitCallback.html#a549f6828e98c9aeaee9012defa100f74',1,'PxHitCallback::nbTouches()']]],
  ['nbtriggerpairs',['nbTriggerPairs',['../classPxSimulationStatistics.html#abcb6c70a6d7e5146767b0be74db34cde',1,'PxSimulationStatistics']]],
  ['nbwheelqueryresults',['nbWheelQueryResults',['../structPxVehicleWheelQueryResult.html#a60678dd75d1ef6335324e4e9987e044f',1,'PxVehicleWheelQueryResult']]],
  ['needspredefinedbounds',['needsPredefinedBounds',['../structPxBroadPhaseCaps.html#aaff9d2a811a6863dea9939ecb2f26e58',1,'PxBroadPhaseCaps']]],
  ['nextcontact',['nextContact',['../structPxContactStreamIterator.html#a7e153b25314fff172bca67a660ccc8c8',1,'PxContactStreamIterator']]],
  ['nextcontactindex',['nextContactIndex',['../structPxContactStreamIterator.html#a9be505b3ff688521967f7b37feb2f898',1,'PxContactStreamIterator']]],
  ['nextitemset',['nextItemSet',['../structPxContactPairExtraDataIterator.html#a6938e71e6ed8d693a4fe9e1bd3bd9d3a',1,'PxContactPairExtraDataIterator']]],
  ['nextpatch',['nextPatch',['../structPxContactStreamIterator.html#a46de7820400eb295b621f38c79884867',1,'PxContactStreamIterator']]],
  ['nextpatchindex',['nextPatchIndex',['../structPxContactStreamIterator.html#a54397b4d83a700d42ded55dfd6f220ac',1,'PxContactStreamIterator']]],
  ['no_5flink',['NO_LINK',['../structPxSolverConstraintDesc.html#a87d502cd319544604669cb843a239fb0',1,'PxSolverConstraintDesc']]],
  ['nodeindex',['nodeIndex',['../structPxSolverBodyData.html#ac01024b5307ea57e79c7891d89906296',1,'PxSolverBodyData::nodeIndex()'],['../structPxTGSSolverBodyData.html#a4fced225135ff28142c1dbb8281b74a8',1,'PxTGSSolverBodyData::nodeIndex()']]],
  ['nonwalkablemode',['nonWalkableMode',['../classPxControllerDesc.html#ad8286ec8cdb374997b9902a1ef21192c',1,'PxControllerDesc']]],
  ['normal',['normal',['../structPxLocationHit.html#a0e4815489090f4faced5e91f6f6cd336',1,'PxLocationHit::normal()'],['../structPxContactPairPoint.html#a36ae08a170895b4b57eaa1f6488bcd05',1,'PxContactPairPoint::normal()'],['../classPxTriangle.html#afb3fd7854de70dad3983f0e0f21809d6',1,'PxTriangle::normal()']]],
  ['normalize',['normalize',['../structPxExtendedVec3.html#a437090f727eed9091297ebe303b4e36c',1,'PxExtendedVec3::normalize()'],['../classPxPlane.html#a37c94eda03f24e3caed2e7739940c14a',1,'PxPlane::normalize()'],['../classPxQuat.html#a77a42662202126a13f2f9fc12013fe70',1,'PxQuat::normalize()'],['../classPxVec2.html#a4c115c5ab9863553c558518f8b1b4d33',1,'PxVec2::normalize()'],['../classPxVec3.html#ab67c4b05db03b0ceeddc74b1f6f77af5',1,'PxVec3::normalize()'],['../classPxVec4.html#a1c40877f3e03054cbd08a48fc9039cd4',1,'PxVec4::normalize()']]],
  ['normalizefast',['normalizeFast',['../classPxVec3.html#abe30659678fa294743b2eaabe69a8689',1,'PxVec3']]],
  ['normalizesafe',['normalizeSafe',['../classPxVec3.html#a69edea41dcd58f35d35036026bf75dcc',1,'PxVec3']]],
  ['numcontactpatches',['numContactPatches',['../structPxSolverContactDesc.html#a2261ea42204894094ada177641222c9a',1,'PxSolverContactDesc::numContactPatches()'],['../structPxTGSSolverContactDesc.html#ad451864f355f80ff88b943b9f3ec6079',1,'PxTGSSolverContactDesc::numContactPatches()']]],
  ['numcontacts',['numContacts',['../structPxSolverContactDesc.html#ae2a5692ebc3c99c68ac34828d15ef56d',1,'PxSolverContactDesc::numContacts()'],['../structPxTGSSolverContactDesc.html#a71566924a2d0ebc51d688318309e0e7e',1,'PxTGSSolverContactDesc::numContacts()']]],
  ['numfrictionpatches',['numFrictionPatches',['../structPxSolverContactDesc.html#ada1b86bf21e1dd614e7e4a07a9c990dd',1,'PxSolverContactDesc::numFrictionPatches()'],['../structPxTGSSolverContactDesc.html#a52c82757413cf7a74fd33543be21f9bc',1,'PxTGSSolverContactDesc::numFrictionPatches()']]],
  ['numprimsperleaf',['numPrimsPerLeaf',['../structPxBVH34MidphaseDesc.html#aa70a3cfbaeff0b25b86f9584760ae563',1,'PxBVH34MidphaseDesc']]],
  ['numrows',['numRows',['../structPxSolverConstraintPrepDesc.html#a70cd18a2d279f25baab00ef7838dec16',1,'PxSolverConstraintPrepDesc::numRows()'],['../structPxTGSSolverConstraintPrepDesc.html#a6fa8f15b3d25c668667d45ab0493d637',1,'PxTGSSolverConstraintPrepDesc::numRows()']]]
];
